@@ -2,7 +2,7 @@ use 5.006;
 
 package WWW::Scripter;
 
-our $VERSION = '0.029';
+our $VERSION = '0.030';
 
 use strict; use warnings; no warnings qw 'utf8 parenthesis bareword';
 
@@ -146,7 +146,7 @@ sub title { (shift->document||return)->title(@_) }
 
 sub content {
 	my $self = shift;
-	if($self->is_html) {
+	if($self->is_html && $self->document) {
 		my %parms = @_;
 		my $cs = (my $doc = $self->document)->charset;;
 		if(exists $parms{format} && $parms{format} eq 'text') {
@@ -312,7 +312,7 @@ sub _update_page {
      !defined $$self{Scripter_dumb} || $$self{Scripter_dumb}
      and $self->is_html
     ) {
-        $self->update_html($content);
+        $res = $self->update_html($content);
     }
     else {
         $self->{content} = $content;
@@ -349,7 +349,7 @@ sub update_html {
 	if(my $doc = $document{$res}) {
 		$self->document($doc);
 		$self->{form} = ($self->{forms} = $doc->forms)->[0];
-		return;
+		return $res;
 	}
 
 	my $life_raft = $self;
@@ -554,7 +554,7 @@ sub update_html {
 	# banana
 	$self->{form} ||= $self->{forms}[0];
 
-	return;
+	return $self->{res};
 }
 
 # Not an override, but used by update_html
